@@ -5,8 +5,9 @@ from .lib.util import objects, exceptions
 
 
 class Client(object):
-    def __init__(self, mongoUri: str):
+    def __init__(self, mongoUri: str, siteUrl: str):
         self.mongoDb = mongoUri
+        self.siteUri = siteUrl
     # if self.mongoUri is None:
     #     return print('Error: No mongoUri defined...')
 
